==> magics++_2.8.0.dfsg.orig.tar.gz: magics++-2.8.0.dfsg/src/decoders/SymbolInput.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file SymbolInput.h
    \brief Definition of the Template class SymbolInput.
    
    Magics Team - ECMWF 2005
    
    Started: Tue 19-Apr-2005
    
    Changes:
    
*/

#ifndef SymbolInput_H
#define SymbolInput_H

#include "magics.h"


#include "Data.h"
#include "SymbolInputAttributes.h"


namespace magics {

template <class P>
class SymbolInput: 
	public Data<P>,
	public SymbolInputAttributes {

public:
	SymbolInput() {}
	virtual ~SymbolInput() {}
	
	 // Implements the set method ... 
    void set(const map<string, string>& map ) { SymbolInputAttributes::set(map); }
   

    virtual void decodePoints() { 
    	if ( value_.empty() )
		  	for (doublearray::iterator x = x_.begin(); x != x_.end(); x++)
    			value_.push_back(0);
    	
    	doublearray::iterator x = x_.begin();
    	doublearray::iterator y = y_.begin();
    	doublearray::iterator v = value_.begin();
    	
    	while ( x != x_.end() && y != y_.end() && v != value_.end() ) {
    		points_.push_back(P(*x, *y, *v));
    		x++;
    		y++;
    		v++;
    	}
    	
    }
  
    
    PointsHandler<P>& points() { 
    	decodePoints(); 
    	this->pointsHandlers_.push_back(new PointsHandler<P>(points_));
    	return  (*this->pointsHandlers_.back());
    } 

protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream& out) const 
	 	{ 
	 		out << "SymbolInput[";
	 		SymbolInputAttributes::print(out);
	 		out << "]";
	 	}
	 PointsList<P> points_;
	
private:
    //! Copy constructor - No copy allowed
	SymbolInput(const SymbolInput&);
    //! Overloaded << operator to copy - No copy allowed
	SymbolInput& operator=(const SymbolInput&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const SymbolInput<P>& p)
		{ p.print(s); return s; }

};

} // namespace magics


#endif

==> magics++_2.10.0.dfsg.orig.tar.gz: magics++-2.10.0.dfsg/src/decoders/SymbolInput.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file SymbolInput.h
    \brief Definition of the Template class SymbolInput.
    
    Magics Team - ECMWF 2005
    
    Started: Tue 19-Apr-2005
    
    Changes:
    
*/

#ifndef SymbolInput_H
#define SymbolInput_H

#include "magics.h"


#include "Data.h"
#include "SymbolInputAttributes.h"


namespace magics {

template <class P>
class SymbolInput: 
	public Data<P>,
	public SymbolInputAttributes {

public:
	SymbolInput() {}
	virtual ~SymbolInput() {}
	
	 // Implements the set method ... 
    void set(const map<string, string>& map ) { SymbolInputAttributes::set(map); }
   

    virtual void decodePoints() { 
    	if ( value_.empty() )
		  	for (doublearray::iterator x = x_.begin(); x != x_.end(); x++)
    			value_.push_back(0);
    	
    	doublearray::iterator x = x_.begin();
    	doublearray::iterator y = y_.begin();
    	doublearray::iterator v = value_.begin();
    	
    	while ( x != x_.end() && y != y_.end() && v != value_.end() ) {
    		points_.push_back(P(*x, *y, *v));
    		x++;
    		y++;
    		v++;
    	} 	
    }
    
    virtual void decodePoints(const Transformation& projection) { 
        	if ( value_.empty() )
    		  	for (doublearray::iterator x = x_.begin(); x != x_.end(); x++)
        			value_.push_back(0);
        	
        	doublearray::iterator x = x_.begin();
        	doublearray::iterator y = y_.begin();
        	doublearray::iterator v = value_.begin();
        	
        	while ( x != x_.end() && y != y_.end() && v != value_.end() ) {
        		if ( projection.in(*x, *y) ) 
        			points_.push_back(P(*x, *y, *v));
        		x++;
        		y++;
        		v++;
        	} 	
        }
  
    
    PointsHandler<P>& points() { 
    	decodePoints(); 
    	this->pointsHandlers_.push_back(new PointsHandler<P>(points_));
    	return  (*this->pointsHandlers_.back());
    }   
    
    PointsHandler<P>& points(const Transformation& transformation) { 
    	decodePoints(transformation); 
    	this->pointsHandlers_.push_back(new PointsHandler<P>(points_));
    	return  (*this->pointsHandlers_.back());
    } 

protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream& out) const 
	 	{ 
	 		out << "SymbolInput[";
	 		SymbolInputAttributes::print(out);
	 		out << "]";
	 	}
	 PointsList<P> points_;
	
private:
    //! Copy constructor - No copy allowed
	SymbolInput(const SymbolInput&);
    //! Overloaded << operator to copy - No copy allowed
	SymbolInput& operator=(const SymbolInput&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const SymbolInput<P>& p)
		{ p.print(s); return s; }

};

} // namespace magics


#endif
